<?php
/**
* Sidebar Metabox.
*
* @package Sakka
*/

add_action( 'add_meta_boxes', 'sakka_metabox' );

if( ! function_exists( 'sakka_metabox' ) ):


    function sakka_metabox() {
        
        add_meta_box(
            'twp-custom-metabox',
            esc_html__( 'Single Post Settings', 'sakka' ),
            'sakka_post_metafield_callback',
            'post', 
            'normal', 
            'high'
        );
    }

endif;

$sakka_single_layout_options = array(
    'layout-1' => esc_html__( 'Simple Layout', 'sakka' ),
    'layout-2' => esc_html__( 'Banner Layout', 'sakka' ),
);


$sakka_post_sidebar_fields = array(
    'global-sidebar' => array(
                    'id'        => 'post-global-sidebar',
                    'value' => 'global-sidebar',
                    'label' => esc_html__( 'Global sidebar', 'sakka' ),
                ),
    'right-sidebar' => array(
                    'id'        => 'post-left-sidebar',
                    'value' => 'right-sidebar',
                    'label' => esc_html__( 'Right sidebar', 'sakka' ),
                ),
    'left-sidebar' => array(
                    'id'        => 'post-right-sidebar',
                    'value'     => 'left-sidebar',
                    'label'     => esc_html__( 'Left sidebar', 'sakka' ),
                ),
    'no-sidebar' => array(
                    'id'        => 'post-no-sidebar',
                    'value'     => 'no-sidebar',
                    'label'     => esc_html__( 'No sidebar', 'sakka' ),
                ),
);

/**
 * Callback function for post option.
*/
if( ! function_exists( 'sakka_post_metafield_callback' ) ):
    
	function sakka_post_metafield_callback() {

		global $post, $sakka_single_layout_options, $sakka_post_sidebar_fields;
        $post_type = get_post_type($post->ID);
		wp_nonce_field( basename( __FILE__ ), 'sakka_post_meta_nonce' ); ?>
        
        <div class="metabox-main-block">

            <div class="metabox-navbar">
                <ul>

                    <li>
                        <a id="metabox-navbar-appearance" class="metabox-navbar-active" href="javascript:void(0)">

                            <?php esc_html_e('Appearance Settings', 'sakka'); ?>

                        </a>
                    </li>

                    <?php
                    if( class_exists('Booster_Extension_Class') ){ ?>

                        <li>
                            <a id="twp-tab-booster" href="javascript:void(0)">

                                <?php esc_html_e('Booster Extension Settings', 'sakka'); ?>

                            </a>
                        </li>

                    <?php } ?>

                </ul>
            </div>

            <div class="twp-tab-content">

                <?php if( $post_type == 'post' ): ?>

                    <div id="metabox-navbar-appearance-content" class="metabox-content-wrap metabox-content-wrap-active">

                         <div class="metabox-opt-panel">

                            <h3 class="meta-opt-title"><?php esc_html_e('Navigation Setting','sakka'); ?></h3>

                            <?php
                            $twp_disable_ajax_load_next_post = esc_attr( get_post_meta($post->ID, 'twp_disable_ajax_load_next_post', true) ); ?>
                            <div class="metabox-opt-wrap metabox-opt-wrap-alt">

                                <label><b><?php esc_html_e( 'Navigation Type','sakka' ); ?></b></label>

                                <select name="twp_disable_ajax_load_next_post">

                                    <option <?php if( $twp_disable_ajax_load_next_post == '' || $twp_disable_ajax_load_next_post == 'global-layout' ){ echo 'selected'; } ?> value="global-layout"><?php esc_html_e('Global Layout','sakka'); ?></option>
                                    <option <?php if( $twp_disable_ajax_load_next_post == 'no-navigation' ){ echo 'selected'; } ?> value="no-navigation"><?php esc_html_e('Disable Navigation','sakka'); ?></option>
                                    <option <?php if( $twp_disable_ajax_load_next_post == 'theme-normal-navigation' ){ echo 'selected'; } ?> value="theme-normal-navigation"><?php esc_html_e('Next Previous Navigation','sakka'); ?></option>
                                    <option <?php if( $twp_disable_ajax_load_next_post == 'ajax-next-post-load' ){ echo 'selected'; } ?> value="ajax-next-post-load"><?php esc_html_e('Ajax Load Next 3 Posts Contents','sakka'); ?></option>

                                </select>

                            </div>

                        </div>

                    </div>

                <?php endif; ?>

                <div class="metabox-opt-panel">

                    <h3 class="meta-opt-title"><?php esc_html_e('Single Page/Post','sakka'); ?></h3>

                    <div class="metabox-opt-wrap metabox-opt-wrap-alt">

                        <?php
                        $sakka_single_layout = esc_html( get_post_meta( $post->ID, 'sakka_single_layout', true ) ); 
                        foreach ( $sakka_single_layout_options as $key => $sakka_single_layout_option) { ?>

                            <label class="description">
                                <input type="radio" name="sakka_single_layout" value="<?php echo esc_attr( $key ); ?>" <?php if( $key == $sakka_single_layout ){ echo "checked='checked'";} ?>/>&nbsp;<?php echo esc_html( $sakka_single_layout_option ); ?>
                            </label>

                        <?php } ?>

                    </div>

                </div>

                <div id="metabox-navbar-general-content" class="metabox-content-wrap metabox-content-wrap-active">

                    <div class="metabox-opt-panel">

                        <h3 class="meta-opt-title"><?php esc_html_e('Sidebar Layout','sakka'); ?></h3>

                        <div class="metabox-opt-wrap metabox-opt-wrap-alt">

                            <?php
                            $sakka_post_sidebar = esc_html( get_post_meta( $post->ID, 'sakka_post_sidebar_option', true ) ); 
                            if( $sakka_post_sidebar == '' ){ $sakka_post_sidebar = 'global-sidebar'; }

                            foreach ( $sakka_post_sidebar_fields as $sakka_post_sidebar_field) { ?>

                                <label class="description">

                                    <input type="radio" name="sakka_post_sidebar_option" value="<?php echo esc_attr( $sakka_post_sidebar_field['value'] ); ?>" <?php if( $sakka_post_sidebar_field['value'] == $sakka_post_sidebar ){ echo "checked='checked'";} if( empty( $sakka_post_sidebar ) && $sakka_post_sidebar_field['value']=='right-sidebar' ){ echo "checked='checked'"; } ?>/>&nbsp;<?php echo esc_html( $sakka_post_sidebar_field['label'] ); ?>

                                </label>

                            <?php } ?>

                        </div>

                    </div>

                </div>
                <?php 
                $sakka_ed_post_views = esc_html( get_post_meta( $post->ID, 'sakka_ed_post_views', true ) );
                $sakka_ed_post_read_time = esc_html( get_post_meta( $post->ID, 'sakka_ed_post_read_time', true ) );
                $sakka_ed_post_like_dislike = esc_html( get_post_meta( $post->ID, 'sakka_ed_post_like_dislike', true ) );
                $sakka_ed_post_author_box = esc_html( get_post_meta( $post->ID, 'sakka_ed_post_author_box', true ) );
                $sakka_ed_post_social_share = esc_html( get_post_meta( $post->ID, 'sakka_ed_post_social_share', true ) );
                $sakka_ed_post_reaction = esc_html( get_post_meta( $post->ID, 'sakka_ed_post_reaction', true ) );
                $sakka_ed_post_rating = esc_html( get_post_meta( $post->ID, 'sakka_ed_post_rating', true ) ); ?>

                <div id="twp-tab-booster-content" class="metabox-content-wrap">

                    <div class="metabox-opt-panel">

                        <h3 class="meta-opt-title"><?php esc_html_e('Booster Extension Plugin Content','sakka'); ?></h3>

                        <div class="metabox-opt-wrap twp-checkbox-wrap">

                            <input type="checkbox" id="sakka-ed-post-views" name="sakka_ed_post_views" value="1" <?php if( $sakka_ed_post_views ){ echo "checked='checked'";} ?>/>
                            <label for="sakka-ed-post-views"><?php esc_html_e( 'Disable Post Views','sakka' ); ?></label>

                        </div>

                        <div class="metabox-opt-wrap twp-checkbox-wrap">

                            <input type="checkbox" id="sakka-ed-post-read-time" name="sakka_ed_post_read_time" value="1" <?php if( $sakka_ed_post_read_time ){ echo "checked='checked'";} ?>/>
                            <label for="sakka-ed-post-read-time"><?php esc_html_e( 'Disable Post Read Time','sakka' ); ?></label>

                        </div>

                        <div class="metabox-opt-wrap twp-checkbox-wrap">

                            <input type="checkbox" id="sakka-ed-post-like-dislike" name="sakka_ed_post_like_dislike" value="1" <?php if( $sakka_ed_post_like_dislike ){ echo "checked='checked'";} ?>/>
                            <label for="sakka-ed-post-like-dislike"><?php esc_html_e( 'Disable Post Like Dislike','sakka' ); ?></label>

                        </div>

                        <div class="metabox-opt-wrap twp-checkbox-wrap">

                            <input type="checkbox" id="sakka-ed-post-author-box" name="sakka_ed_post_author_box" value="1" <?php if( $sakka_ed_post_author_box ){ echo "checked='checked'";} ?>/>
                            <label for="sakka-ed-post-author-box"><?php esc_html_e( 'Disable Post Author Box','sakka' ); ?></label>

                        </div>

                        <div class="metabox-opt-wrap twp-checkbox-wrap">

                            <input type="checkbox" id="sakka-ed-post-social-share" name="sakka_ed_post_social_share" value="1" <?php if( $sakka_ed_post_social_share ){ echo "checked='checked'";} ?>/>
                            <label for="sakka-ed-post-social-share"><?php esc_html_e( 'Disable Post Social Share','sakka' ); ?></label>

                        </div>

                        <div class="metabox-opt-wrap twp-checkbox-wrap">

                            <input type="checkbox" id="sakka-ed-post-reaction" name="sakka_ed_post_reaction" value="1" <?php if( $sakka_ed_post_reaction ){ echo "checked='checked'";} ?>/>
                            <label for="sakka-ed-post-reaction"><?php esc_html_e( 'Disable Post Reaction','sakka' ); ?></label>

                        </div>

                        <div class="metabox-opt-wrap twp-checkbox-wrap">

                            <input type="checkbox" id="sakka-ed-post-rating" name="sakka_ed_post_rating" value="1" <?php if( $sakka_ed_post_rating ){ echo "checked='checked'";} ?>/>
                            <label for="sakka-ed-post-rating"><?php esc_html_e( 'Disable Post Rating','sakka' ); ?></label>

                        </div>

                    </div>

                </div>
                
            </div>

        </div>  
            
    <?php }
endif;

// Save metabox value.
add_action( 'save_post', 'sakka_save_post_meta' );

if( ! function_exists( 'sakka_save_post_meta' ) ):

    function sakka_save_post_meta( $post_id ) {

        global $post, $sakka_single_layout_options, $sakka_post_sidebar_fields;

        if ( !isset( $_POST[ 'sakka_post_meta_nonce' ] ) || !wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['sakka_post_meta_nonce'] ) ), basename( __FILE__ ) ) ){

            return;

        }

        if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ){

            return;

        }
            
        if ( 'page' == $_POST['post_type'] ) {  

            if ( !current_user_can( 'edit_page', $post_id ) ){  

                return $post_id;

            }

        }elseif( !current_user_can( 'edit_post', $post_id ) ) {

            return $post_id;

        }

        $twp_disable_ajax_load_next_post_old = sanitize_text_field( get_post_meta( $post_id, 'twp_disable_ajax_load_next_post', true ) ); 
        $twp_disable_ajax_load_next_post_new = isset( $_POST['twp_disable_ajax_load_next_post'] ) ? sakka_sanitize_meta_pagination( wp_unslash( $_POST['twp_disable_ajax_load_next_post'] ) ) : '' ;
        if( $twp_disable_ajax_load_next_post_new && $twp_disable_ajax_load_next_post_new != $twp_disable_ajax_load_next_post_old ){

            update_post_meta ( $post_id, 'twp_disable_ajax_load_next_post', $twp_disable_ajax_load_next_post_new );

        }elseif( '' == $twp_disable_ajax_load_next_post_new && $twp_disable_ajax_load_next_post_old ) {

            delete_post_meta( $post_id,'twp_disable_ajax_load_next_post', $twp_disable_ajax_load_next_post_old );

        }

        foreach ( $sakka_post_sidebar_fields as $sakka_post_sidebar_field ) {  
            

                $old = esc_html( get_post_meta( $post_id, 'sakka_post_sidebar_option', true ) ); 
                $new = isset( $_POST['sakka_post_sidebar_option'] ) ? sakka_sanitize_sidebar_option_meta( wp_unslash( $_POST['sakka_post_sidebar_option'] ) ) : '';

                if ( $new && $new != $old ){

                    update_post_meta ( $post_id, 'sakka_post_sidebar_option', $new );

                }elseif( '' == $new && $old ) {

                    delete_post_meta( $post_id,'sakka_post_sidebar_option', $old );

                }

            
        }


        foreach ( $sakka_single_layout_options as $sakka_single_layout_option ) {  
            
            $sakka_single_layout_old = sanitize_text_field( get_post_meta( $post_id, 'sakka_single_layout', true ) ); 
            $sakka_single_layout_new = sanitize_text_field( wp_unslash( $_POST['sakka_single_layout'] ) );

            if ( $sakka_single_layout_new && $sakka_single_layout_new != $sakka_single_layout_old ){

                update_post_meta ( $post_id, 'sakka_single_layout', $sakka_single_layout_new );

            }elseif( '' == $sakka_single_layout_new && $sakka_single_layout_old ) {

                delete_post_meta( $post_id,'sakka_single_layout', $sakka_single_layout_old );

            }
            
        }
        
        $sakka_ed_feature_image_old = absint( get_post_meta( $post_id, 'sakka_ed_feature_image', true ) );
        $sakka_ed_feature_image_new = isset( $_POST['sakka_ed_feature_image'] ) ? absint( wp_unslash( $_POST['sakka_ed_feature_image'] ) ) : '';

        if ( $sakka_ed_feature_image_new && $sakka_ed_feature_image_new != $sakka_ed_feature_image_old ){

            update_post_meta ( $post_id, 'sakka_ed_feature_image', $sakka_ed_feature_image_new );

        }elseif( '' == $sakka_ed_feature_image_new && $sakka_ed_feature_image_old ) {

            delete_post_meta( $post_id,'sakka_ed_feature_image', $sakka_ed_feature_image_old );

        }

        $sakka_ed_post_views_old = absint( get_post_meta( $post_id, 'sakka_ed_post_views', true ) );
        $sakka_ed_post_views_new = isset( $_POST['sakka_ed_post_views'] ) ? absint( wp_unslash( $_POST['sakka_ed_post_views'] ) ) : '';

        if ( $sakka_ed_post_views_new && $sakka_ed_post_views_new != $sakka_ed_post_views_old ){

            update_post_meta ( $post_id, 'sakka_ed_post_views', $sakka_ed_post_views_new );

        }elseif( '' == $sakka_ed_post_views_new && $sakka_ed_post_views_old ) {

            delete_post_meta( $post_id,'sakka_ed_post_views', $sakka_ed_post_views_old );

        }

        $sakka_ed_post_read_time_old = absint( get_post_meta( $post_id, 'sakka_ed_post_read_time', true ) );
        $sakka_ed_post_read_time_new = isset( $_POST['sakka_ed_post_read_time'] ) ? absint( wp_unslash( $_POST['sakka_ed_post_read_time'] ) ) : '';

        if ( $sakka_ed_post_read_time_new && $sakka_ed_post_read_time_new != $sakka_ed_post_read_time_old ){

            update_post_meta ( $post_id, 'sakka_ed_post_read_time', $sakka_ed_post_read_time_new );

        }elseif( '' == $sakka_ed_post_read_time_new && $sakka_ed_post_read_time_old ) {

            delete_post_meta( $post_id,'sakka_ed_post_read_time', $sakka_ed_post_read_time_old );

        }

        $sakka_ed_post_like_dislike_old = absint( get_post_meta( $post_id, 'sakka_ed_post_like_dislike', true ) );
        $sakka_ed_post_like_dislike_new = isset( $_POST['sakka_ed_post_like_dislike'] ) ? absint( wp_unslash( $_POST['sakka_ed_post_like_dislike'] ) ) : '';

        if ( $sakka_ed_post_like_dislike_new && $sakka_ed_post_like_dislike_new != $sakka_ed_post_like_dislike_old ){

            update_post_meta ( $post_id, 'sakka_ed_post_like_dislike', $sakka_ed_post_like_dislike_new );

        }elseif( '' == $sakka_ed_post_like_dislike_new && $sakka_ed_post_like_dislike_old ) {

            delete_post_meta( $post_id,'sakka_ed_post_like_dislike', $sakka_ed_post_like_dislike_old );

        }

        $sakka_ed_post_author_box_old = absint( get_post_meta( $post_id, 'sakka_ed_post_author_box', true ) );
        $sakka_ed_post_author_box_new = isset( $_POST['sakka_ed_post_author_box'] ) ? absint( wp_unslash( $_POST['sakka_ed_post_author_box'] ) ) : '';

        if ( $sakka_ed_post_author_box_new && $sakka_ed_post_author_box_new != $sakka_ed_post_author_box_old ){

            update_post_meta ( $post_id, 'sakka_ed_post_author_box', $sakka_ed_post_author_box_new );

        }elseif( '' == $sakka_ed_post_author_box_new && $sakka_ed_post_author_box_old ) {

            delete_post_meta( $post_id,'sakka_ed_post_author_box', $sakka_ed_post_author_box_old );

        }

        $sakka_ed_post_social_share_old = absint( get_post_meta( $post_id, 'sakka_ed_post_social_share', true ) );
        $sakka_ed_post_social_share_new = isset( $_POST['sakka_ed_post_social_share'] ) ? absint( wp_unslash( $_POST['sakka_ed_post_social_share'] ) ) : '';

        if ( $sakka_ed_post_social_share_new && $sakka_ed_post_social_share_new != $sakka_ed_post_social_share_old ){

            update_post_meta ( $post_id, 'sakka_ed_post_social_share', $sakka_ed_post_social_share_new );

        }elseif( '' == $sakka_ed_post_social_share_new && $sakka_ed_post_social_share_old ) {

            delete_post_meta( $post_id,'sakka_ed_post_social_share', $sakka_ed_post_social_share_old );

        }

        $sakka_ed_post_reaction_old = absint( get_post_meta( $post_id, 'sakka_ed_post_reaction', true ) );
        $sakka_ed_post_reaction_new = isset( $_POST['sakka_ed_post_reaction'] ) ? absint( wp_unslash( $_POST['sakka_ed_post_reaction'] ) ) : '';

        if ( $sakka_ed_post_reaction_new && $sakka_ed_post_reaction_new != $sakka_ed_post_reaction_old ){

            update_post_meta ( $post_id, 'sakka_ed_post_reaction', $sakka_ed_post_reaction_new );

        }elseif( '' == $sakka_ed_post_reaction_new && $sakka_ed_post_reaction_old ) {

            delete_post_meta( $post_id,'sakka_ed_post_reaction', $sakka_ed_post_reaction_old );

        }

        $sakka_ed_post_rating_old = absint( get_post_meta( $post_id, 'sakka_ed_post_rating', true ) );
        $sakka_ed_post_rating_new = isset( $_POST['sakka_ed_post_rating'] ) ? absint( wp_unslash( $_POST['sakka_ed_post_rating'] ) ) : '';

        if ( $sakka_ed_post_rating_new && $sakka_ed_post_rating_new != $sakka_ed_post_rating_old ){

            update_post_meta ( $post_id, 'sakka_ed_post_rating', $sakka_ed_post_rating_new );

        }elseif( '' == $sakka_ed_post_rating_new && $sakka_ed_post_rating_old ) {

            delete_post_meta( $post_id,'sakka_ed_post_rating', $sakka_ed_post_rating_old );

        }

    }

endif;   